@@ -1,6 +1,5 @@
 from django.db import models
 from django.utils.functional import cached_property
-from django.http import HttpResponse
 from django.conf import settings
 from wagtail.admin.edit_handlers import MultiFieldPanel, StreamFieldPanel, PageChooserPanel
 from wagtail.images.edit_handlers import ImageChooserPanel
@@ -10,7 +9,7 @@ from wagtail.core.models import Page
 from wagtail.admin.edit_handlers import FieldPanel, InlinePanel
 from wagtail.core.utils import camelcase_to_underscore
 from modelcluster.fields import ParentalKey
-from wagtail.core.models import Orderable
+from wagtail.core.models import Orderable, Site
 
 from webspace.bakery.models import VersionBuild
 from webspace.cms.amp.mixins import AmpMixin
@@ -183,6 +182,7 @@ class AGenericPage(Page):
         context['debug'] = settings.DEBUG
         context['icons'] = IconSnippet.get_context()
         context['version'] = VersionBuild.get().version
+        context['site'] = Site.find_for_request(request)
         context['studio'] = {
             'name': constants.STUDIO_NAME,
             'email': constants.STUDIO_EMAIL,
