@@ -152,20 +152,20 @@ const Aside = {
 
 const Lazy = {
   init: () => {
-    if ('loading' in HTMLImageElement.prototype) {
-      const elements = document.querySelectorAll('*[loading="lazy"]');
-      elements.forEach((element) => {
+    const io = new IntersectionObserver(entries => entries.forEach((entry) => {
+      if (entry.isIntersecting) {
+        const element = entry.target;
         if (element.id.startsWith('slide-')) {
+          // background
           element.style.backgroundImage = `url(${element.dataset.src})`;
         } else {
+          // classic
           element.src = element.dataset.src;
         }
-      });
-    } else {
-      const script = document.createElement('script');
-      script.src = 'https://cdnjs.cloudflare.com/ajax/libs/lazysizes/5.1.2/lazysizes.min.js';
-      document.body.appendChild(script);
-    }
+        io.unobserve(element);
+      }
+    }));
+    document.querySelectorAll('*[loading="lazy"]').forEach(element => io.observe(element));
   },
 };
 
